# disckit
![Python](https://img.shields.io/badge/Python-3.11%20%7C%203.12%20%7C%203.13-blue)

An open source utilities library for the disutils bots

> [!WARNING]
> **Note:** This package exclusively supports **Application Commands only** for the API wrapper [discord.py](https://github.com/Rapptz/discord.py).\
This package may cause unexepected behaviour if used with any other API wrapper or forks of `discord.py`.

# Analytics
![Alt](https://repobeats.axiom.co/api/embed/90c2ae330c90d87026c048335eac0923d31b683f.svg "Repobeats analytics image")

# Documentation
This library doesn't support any website documentation yet but all classes and functions have been fully documented in the codebase.
If you require examples on the usage of this library please check this [repo](https://github.com/disutils/disckit-example-bot).